@@ -22,11 +22,11 @@ static void test_uid_wrapper_enabled(void **state)
 int main(void) {
 	int rc;
 
-	const UnitTest tests[] = {
-		unit_test(test_uid_wrapper_enabled),
+	const struct CMUnitTest tests[] = {
+		cmocka_unit_test(test_uid_wrapper_enabled),
 	};
 
-	rc = run_tests(tests);
+	rc = cmocka_run_group_tests(tests, NULL, NULL);
 
 	return rc;
 }
